# [Zope-tests] OK : Zope Buildbot / zopetoolkit-1.1-py2.5 slave-ubuntu64

jdriessen at thehealthagency.com jdriessen at thehealthagency.com
Tue Feb 1 00:52:57 EST 2011

- Previous message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-1.0-py2.6 slave-ubuntu64
- Next message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-1.0_win-py2.6 slave-win
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : Zope Buildbot / zopetoolkit-1.1-py2.5 slave-ubuntu64
    Build: http://dev.thehealthagency.com/buildbot/builders/zopetoolkit-1.1-py2.5%20slave-ubuntu64/builds/26

    Build Reason: The Periodic scheduler named 'Periodic scheduler for zopetoolkit-1.1-py2.5' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://dev.thehealthagency.com/buildbot/

- Previous message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-1.0-py2.6 slave-ubuntu64
- Next message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-1.0_win-py2.6 slave-win
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list